changeset 9373:ab2633b3f053 draft

(svn r13277) -Fix: opntitle 'jumping' to the temperate climate when closing the NewGRF settings window.
author rubidium <rubidium@openttd.org>
date Mon, 26 May 2008 21:38:17 +0000
parents 91ee716a469b
children 8bf5fed72757
files src/genworld_gui.cpp src/openttd.cpp src/settings.cpp src/settings_func.h
diffstat 4 files changed, 8 insertions(+), 19 deletions(-) [+]
line wrap: on
line diff
--- a/src/genworld_gui.cpp
+++ b/src/genworld_gui.cpp
@@ -205,7 +205,7 @@
 	DeleteAllNonVitalWindows();
 
 	/* Copy all XXX_newgame to XXX when coming from outside the editor */
-	UpdatePatches();
+	_settings = _settings_newgame;
 	ResetGRFConfig(true);
 
 	SndPlayFx(SND_15_BEEP);
@@ -377,7 +377,7 @@
 				break;
 
 			case GLAND_GENERATE_BUTTON: // Generate
-				UpdatePatches();
+				_settings = _settings_newgame;
 
 				if (_settings.economy.town_layout == TL_NO_ROADS) {
 					ShowQuery(
--- a/src/settings.cpp
+++ b/src/settings.cpp
@@ -2265,22 +2265,16 @@
 
 void CheckConfig()
 {
-	// Increase old default values for pf_maxdepth and pf_maxlength
-	// to support big networks.
+	/*
+	 * Increase old default values for pf_maxdepth and pf_maxlength
+	 * to support big networks.
+	 */
 	if (_settings_newgame.pf.opf.pf_maxdepth == 16 && _settings_newgame.pf.opf.pf_maxlength == 512) {
 		_settings_newgame.pf.opf.pf_maxdepth = 48;
 		_settings_newgame.pf.opf.pf_maxlength = 4096;
 	}
 }
 
-void UpdatePatches()
-{
-	/* Since old(er) savegames don't have any patches saved, we initialise
-	 * them with the default values just as it was in the old days.
-	 * Also new games need this copying-over */
-	_settings = _settings_newgame; /* backwards compatibility */
-}
-
 extern const ChunkHandler _setting_chunk_handlers[] = {
 	{ 'OPTS', NULL,      Load_OPTS, CH_RIFF},
 	{ 'PATS', Save_PATS, Load_PATS, CH_RIFF | CH_LAST},
--- a/src/settings_func.h
+++ b/src/settings_func.h
@@ -12,6 +12,5 @@
 void LoadFromConfig();
 void SaveToConfig();
 void CheckConfig();
-void UpdatePatches();
 
 #endif /* SETTINGS_FUNC_H */
--- a/src/openttd.cpp
+++ b/src/openttd.cpp
@@ -588,10 +588,8 @@
 	/* XXX - ugly hack, if diff_level is 9, it means we got no setting from the config file */
 	if (_settings_newgame.difficulty.diff_level == 9) SetDifficultyLevel(0, &_settings_newgame.difficulty);
 
-	/* Make sure _patches is filled with _patches_newgame if we switch to a game directly */
-	if (_switch_mode != SM_NONE) {
-		UpdatePatches();
-	}
+	/* Make sure _settings is filled with _settings_newgame if we switch to a game directly */
+	if (_switch_mode != SM_NONE) _settings = _settings_newgame;
 
 	/* initialize the ingame console */
 	IConsoleInit();
@@ -1916,8 +1914,6 @@
 		}
 	}
 
-	if (CheckSavegameVersion(22))  UpdatePatches();
-
 	if (CheckSavegameVersion(25)) {
 		Vehicle *v;
 		FOR_ALL_VEHICLES(v) {